#
# spec file for package sakura
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sakura
Version:        3.8.8
Release:        1.3
Summary:        Terminal Emulator based on the VTE Library
License:        GPL-2.0-or-later
URL:            https://launchpad.net/sakura
Source:         https://launchpad.net/sakura/trunk/%{version}/+download/sakura-%{version}.tar.bz2
Patch0:         sakura-icon.patch
Patch1:         sakura-fix_pod2man.patch
# to convert SVG to PNG:
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  intltool
BuildRequires:  libstdc++-devel
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.20
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(vte-2.91) >= 0.38

%description
sakura is a vte-based terminal emulator. It aims to provide a terminal
emulator that only depends on GTK and VTE. It uses a notebook to allow
multiple tabs in the same window.

%lang_package

%prep
%autosetup -p1
mv terminal-tango.svg sakura.svg
convert -strip sakura.svg sakura.png
# replace hard-coded ICON_DIR
sed -i -r 's|^(\s*#define\s*ICON_DIR\s+").+("\s*)$|\1%{_datadir}/pixmaps\2|g' src/sakura.c

%build
%cmake -DCMAKE_C_FLAGS="%{optflags}"
%cmake_build

%install
%cmake_install
rm -rf "%{buildroot}%{_datadir}/doc"
%find_lang %{name} %{?no_lang_C}

%files
%doc AUTHORS
%license LICENSE
%{_bindir}/sakura
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.*
%{_mandir}/man1/sakura.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sun Oct 13 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 3.8.8:
  * Updated translations
  * Removed show closebutton option from the contextual menu
  * Addded a term option to set the default terminal (solves issue #49)
  * Let child processes manage button events if needed (solves issue #48)
  * Disable tab scrolling because it's not working as expected (solves issue #45)
  * Added support for shell programs different from the login shell (non-/bin/bash)
* Wed Jul  5 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 3.8.7:
  * update translations
  * Fixed bug #2011352: pressing tab causes blinking in taskbar
* Tue Aug  9 2022 Dirk Müller <dmueller@suse.com>
- update to 3.8.5:
  * no upstream changelog available
* Thu Jan 13 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.8.4
  * no upstream changelog available
- Refresh patches to apply
- Use cmake_build macro for building
* Wed Apr 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.8.2
  * no upstream changelog available
* Mon Aug 24 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.7.1:
  * no upstream changelog available
* Tue Nov  5 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.7.0
- fix dependencies
* Thu Aug 30 2018 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.6.0
- rebase sakura-icon.patch
- no upstream changelog
* Sat Dec 16 2017 bwiedemann@suse.com
- Use convert -strip to avoid png timestamps that differ between builds
* Thu Nov 30 2017 mimi.vx@gmail.com
- update to 3.5.0
- use cmake macros
- lang subpackage
- drop vte291.patch and refresh sakura-icon.patch
* Sun Feb  8 2015 p.silvaggio@videotron.ca
- update to 3.2.0:
  * no upstream changelog.
- now requires vte >= 0.38
* Sat Dec 21 2013 dap.darkness@gmail.com
- update to 3.1.3:
  * no upstream changelog.
- Removed sakura-gtk.patch that was merged into upstream.
* Mon Dec  2 2013 dap.darkness@gmail.com
- update to 3.1.2:
  * no upstream changelog.
- sakura-icon.patch was updated.
- spec was reactored in modern openSUSE style.
- Added sakura-gtk.patch as a workaround for bnc#853227.
* Mon Apr 19 2010 pascal.bleser@opensuse.org
- update to 2.3.8:
  * fixed a bug about lost keyboard focus
  * add true transparency support if there is a composite manager running
  * add a new item (new window) in the popup menu
  * reorganize the menu
  * updated translations
  * made several small fixes
- now requires vte >= 0.20, dropped backport patch
* Mon Mar  8 2010 pascal.bleser@opensuse.org
- update to 2.3.7:
  * adds detection for running processes when closing sakura,
    instead of counting the number of opened tabs
  * a man page bug has been fixed
  * updated translations
* Sun May 31 2009 pascal.bleser@opensuse.org
- properly pass %%%%optflags
- backport for vte < 0.16.15
- update to 2.3.4:
  * an option was added for a blinking cursor
  * the Czech translation was updated
  * the documentation was updated
- changes from 2.3.3:
  * window default size problems were fixed
  * minor changes were made to the close dialog
  * a new Croatian translation
  * an SVG icon were added
* Mon Nov 10 2008 guru@unixtech.be
- scrapped %%changelog entries before 2.3.0
- only apply backport UsePkgConfig patch when the cmake version is < 2.6.x
- update to 2.3.2:
  * adds a new accelerator to open a URL using the left mouse button
  * fixes the maximize bug and other window size problems
  * less verbose when not compiled in debug mode
* Thu Oct 23 2008 guru@unixtech.be
- update to 2.3.1:
  * all dialogs have been improved to conform to HIG recommendations
  * a configuration option has been added to enable/disable the per-tab close
    button
  * strings are used instead of keycodes for easier key bindings configuration
* Fri Sep 26 2008 guru@unixtech.be
- update to 2.3.0:
  * a bug where the scrollbar configuration was not kept has been fixed
  * a close button has been added to tabs (disabled by default)
  * a new terminal bell and palette options have been added
  * a race condition when destroying the sakura window has been fixed
